Firefox3Locator (Selenium RC Server (Coreless) 1.0.1 API)
Date: 2009-06-09

Overview | Package | Class | Use | Tree | Deprecated | Index | Help
PREV CLASS NEXT CLASS | FRAMES NO FRAMES
SUMMARY: NESTED | FIELD | CONSTR | METHOD | DETAIL: FIELD | CONSTR | METHOD

## org.openqa.selenium.server.browserlaunchers.locators
Class Firefox3Locator

    java.lang.Object
      org.openqa.selenium.server.browserlaunchers.locators.SingleBrowserLocator
          org.openqa.selenium.server.browserlaunchers.locators.FirefoxLocator
              org.openqa.selenium.server.browserlaunchers.locators.Firefox3Locator

All Implemented Interfaces:
  BrowserLocator

    public class Firefox3Locator

extends FirefoxLocator

Discovers a valid Firefox 2.x or 3.x installation on local system. Preference is given to 2.x installs.

Constructor Summary
`Firefox3Locator()`

Method Summary
`protected java.lang.String` | `browserName()`
`protected java.lang.String[]` | `firefoxDefaultLocationsOnUbuntu()` Dynamic because the directory version number keep changing.
`protected boolean` | `runningOnWindows()`
`protected java.lang.String` | `seleniumBrowserName()`
`protected java.lang.String[]` | `standardlauncherFilenames()`
`protected java.lang.String[]` | `usualLauncherLocations()`
`protected java.lang.String[]` | `usualUnixLauncherLocations()`

Methods inherited from class org.openqa.selenium.server.browserlaunchers.locators.FirefoxLocator
`browserPathOverridePropertyName`

Methods inherited from class org.openqa.selenium.server.browserlaunchers.locators.SingleBrowserLocator
`browserDefaultPath, computeLibraryPath, couldNotFindAnyInstallationMessage, fakeLauncherPath, findAtADefaultLocation, findBrowserLocation, findBrowserLocationOrFail, findFileInPath, findInPath, humanFriendlyLauncherFileNames, retrieveValidInstallationPath, retrieveValidInstallationPath, retrieveValidInstallationPath`

Methods inherited from class java.lang.Object
`clone, equals, finalize, getClass, hashCode, notify, notifyAll, toString, wait, wait, wait`

Constructor Detail

### Firefox3Locator

    public Firefox3Locator()

Method Detail

### browserName

    protected java.lang.String browserName()

  Specified by:
    `browserName` in class `SingleBrowserLocator`

### seleniumBrowserName

    protected java.lang.String seleniumBrowserName()

  Specified by:
    `seleniumBrowserName` in class `SingleBrowserLocator`

### standardlauncherFilenames

    protected java.lang.String[] standardlauncherFilenames()

  Specified by:
    `standardlauncherFilenames` in class `SingleBrowserLocator`

### usualLauncherLocations

    protected java.lang.String[] usualLauncherLocations()

  Specified by:
    `usualLauncherLocations` in class `SingleBrowserLocator`

### usualUnixLauncherLocations

    protected java.lang.String[] usualUnixLauncherLocations()

### firefoxDefaultLocationsOnUbuntu

    protected java.lang.String[] firefoxDefaultLocationsOnUbuntu()

  Dynamic because the directory version number keep changing.

### runningOnWindows

    protected boolean runningOnWindows()

Overview | Package | Class | Use | Tree | Deprecated | Index | Help
PREV CLASS NEXT CLASS | FRAMES NO FRAMES
SUMMARY: NESTED | FIELD | CONSTR | METHOD | DETAIL: FIELD | CONSTR | METHOD

Copyright © 2009. All Rights Reserved.